# Docprompt

Docprompt is a lightweight library for working with text-rich multimodal inputs to support Large Language Model Workloads

This library has several goals

* Provide abstractions for working with and processing PDF's and images
* Abstractions for document operations with third party providers



[![pypi](https://img.shields.io/pypi/v/docprompt.svg)](https://pypi.org/project/docprompt/)
[![python](https://img.shields.io/pypi/pyversions/docprompt.svg)](https://pypi.org/project/docprompt/)
[![Build Status](https://github.com/psu3d0/docprompt/actions/workflows/dev.yml/badge.svg)](https://github.com/psu3d0/docprompt/actions/workflows/dev.yml)
[![codecov](https://codecov.io/gh/psu3d0/docprompt/branch/main/graphs/badge.svg)](https://codecov.io/github/psu3d0/docprompt)



Documents and large language models


* Documentation: <https://psu3d0.github.io/docprompt>
* GitHub: <https://github.com/Page-Leaf/docprompt>
* PyPI: <https://pypi.org/project/docprompt/>
* Free software: Apache-2.0


## Features

* Representations for common document layout types - `TextBlock`, `BoundingBox`, etc
* Generic implementations of OCR providers

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install Docprompt.

```bash
pip install docprompt
```
